function [x,y,zeta] = elliptical(ty,n,m,q) 


// elliptical.m
// 3D plot of a mode with elliptical boundary conditions
// elliptical(parity,n,m,q);
// parity=''e'' or ''o''
// n = radial order (Ce, Se)
// m = angular order (ce, se)
// q = ... modifies ellipticity (q~=0)
// also outputs radial zeros and ellipse aspect ratio
// do not use q=0! use q=0.01 (or smaller) or Bessel functions 
// (q=0 implies infinite radius, as focal distance is fixed) 

mode(0);										// Display mode
ieee(1);										// Display warning for floating point exception
if ty=="e" then
	tr = "Ce"; 
	ta = "ce";
end												// ''even'' mode

if ty=="o" then
	tr = "Se"; 
	ta = "se";
end												// ''odd'' mode

v=0:0.1:2*%pi+0.2;								// argument of angular function: 0 to 2*pi

umax=2+n^0.3*(q+0.1)^(-0.2);;					// empirical starting point
sol=0.1;
while length(sol)<=n
	u0=0.01:0.01:umax;							// trial radial range 
  	f0=mathieu(tr,m,u0,q);
	f1=f0>0;
	f1=bool2s(f1);
	f2=diff(f1);
	sol=u0(find(f2~=0));						// find zeroes of radial function
	umax=umax+1;
end
u = 0:0.01:sol(n);								// argument corresponding to n-th zero

f = mathieu(tr,m,u,q);
g = mathieu(ta,m,v,q);
[x,y] = ell2cart(u,v,1);						// conversion to cartesian coord. 
												// 1 is semi-distance between foci
axesratio=max(x)/max(y);
ellipticity=(axesratio-1)/(axesratio+1);
zeta=f*g';
mass=max(zeta);
xset("colormap",jetcolormap(128));				//set the colormap
surf(x,y,zeta/mass*max(x),"facecol","interp"); 	//(arbitrary scaling for z)
e=gce();
e.color_mode=-1;								//set the color mode, vanish the mesh
//set(gca(),"isoview","on");					//set the axises x and y equal
set(gca(),"grid",[1,1]);
e.color_flag=3;									//interpolate the facet, to make the surface prettier
//contour(x,y,zeta/mass*max(max(x)),20)      	// a different display
//
//um=min(yy);
//uM=max(yy);
//colorbar(um,uM)								//show the colorbar using min and max values of yy

endfunction
